@@ -1,15 +1,14 @@
 import datetime
-from dataclasses import dataclass, field
-from typing import Union, Text
+from typing import Union
 from unittest import mock
 
-
 try:
     import aws_cdk.core as cdk
     import aws_cdk.aws_s3 as s3
     import aws_cdk.aws_glue as glue
     import aws_cdk.aws_athena as athena
     import jsii
+
     Type = Union[type, glue.Type]
 
 except ImportError:
